<template>
	<el-dialog v-model="dialogVisible" @close="resetForm(ruleFormRef)" :fullscreen="full" :title="titles" width="50%" draggable>
		<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
		<el-form :model="form" ref="ruleFormRef" :rules="rules" :disabled="disabled" label-width="120px">
			<el-row>
				<el-col :xs="24" :sm="12" :md="12" :lg="12" :xl="12" class="mb20">
					<el-form-item label="标题" size="default" prop="caseTitle">
						<el-input v-model="form.caseTitle" />
					</el-form-item>
				</el-col>
				<el-col :xs="24" :sm="11" :md="11" :lg="11" :xl="11" class="mb20">
					<el-form-item label="发布时间" size="default" prop="caseTime">
						<el-date-picker
							v-model="form.caseTime"
							format="YYYY-MM-DD HH:mm:ss"
							value-format="YYYY-MM-DD HH:mm:ss"
							type="datetime"
							placeholder="请选择"
							style="width: 100%"
						/>
					</el-form-item>
				</el-col>
				<el-col :xs="24" :sm="23" :md="23" :lg="23" :xl="23" class="mb20">
					<el-form-item  label="内容" size="default" prop="caseContent">
						<Wangeditor v-if="dialogVisible" style="width: 100%" :value="form.caseContent"
									@change="changeCaseContent" showTop=""></Wangeditor>
					</el-form-item>
				</el-col>
			</el-row>
		</el-form>
		<template #footer>
			<span class="dialog-footer">
				<el-button @click="resetForm(ruleFormRef)" size="default">关闭</el-button>
				<el-button type="primary" v-if="disabled == false" @click="submitForm(ruleFormRef)" size="default">确定</el-button>
			</span>
		</template>
	</el-dialog>
</template>
<script lang="ts">
import { defineComponent, ref, reactive } from 'vue';
import { timeDate } from '/@/assets/index.ts';
import type { FormInstance, FormRules } from 'element-plus';
import { Search, FullScreen } from '@element-plus/icons-vue';
import { ElMessageBox, ElMessage, ElButton, ElInput, TabsPaneContext } from 'element-plus';
import { accidentManagementSystemApi } from '/@/api/accidentManagementSystem';
import Wangeditor from './wangEditor/index.vue';


export default defineComponent({
	components: {Wangeditor},
	setup(props, { emit }) {
		const getWangEditorValue = (str:string) => {
			console.log(str);
		}
		const ruleFormRef = ref<FormInstance>();
		const dialogVisible = ref<boolean>(false);
		const form = ref({
			caseTitle: '',///案例标题
			caseContent: '',///案例内容
			caseTime: '',
		});
		const changeCaseContent = (e) => {
			form.value.caseContent = e
		}
		const targetType = ref();
		const disabled = ref(false);
		const titles = ref();
		const titleT = ref();
		const openDailog = (title: string, id: number) => {
			dialogVisible.value = true;
			titles.value = `${title}事故案例`;
			titleT.value = title;
			// targetType.value = type;
			disabled.value = title == '查看' ? true : false;
			if (title == '查看' || title == '修改') {
				accidentManagementSystemApi()
					.getaccidentCaseDetail(id)
					.then((res) => {
						if (res.data.code == 200) {
							form.value = res.data.data;
						} else {
							ElMessage.error(res.data.msg);
						}
					});
			}
		};
		const rules = reactive<FormRules>({
			caseTitle: [
				{
					required: true,
					message: '案例标题不能为空',
					trigger: 'blur',
				},
			],
			caseTime: [
				{
					required: true,
					message: '发布时间不能为空',
					trigger: 'blur',
				},
			],
		});
		const submitForm = async (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			await formEl.validate((valid, fields) => {
				if (valid) {
					if (titleT.value == '新建') {
						delete form.value.id;
						dialogVisible.value = false;
					accidentManagementSystemApi()
						.getaccidentCaseAdd(form.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
								emit('onAdd');
							} else {
								ElMessage.error(res.data.msg);
							}
						});
					}else{
						dialogVisible.value = false;
					accidentManagementSystemApi()
						.getaccidentCaseUpdata(form.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
								emit('onAdd');
							} else {
								ElMessage.error(res.data.msg);
							}
						});
					}
					
				} else {
					console.log('error submit!', fields);
				}
			});
		};
		const resetForm = (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			formEl.resetFields();
			form.value = {}
			console.log(form.value)
			dialogVisible.value = false;
		};
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		return {
			timeDate,
			ruleFormRef,
			titleT,
			rules,
			submitForm,
			resetForm,
			form,
			dialogVisible,
			openDailog,
			Search,
			full,
			toggleFullscreen,
			FullScreen,
			targetType,
			disabled,
			titles,
			changeCaseContent
		};
	},
});
</script>
<style scoped>
.el-row {
	padding: 0 0 20px 0;
}
</style>